@@ -6,6 +6,7 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.Semaphore;
 
 import javax.activation.DataHandler;
 import javax.xml.ws.WebServiceException;
@@ -62,7 +63,12 @@ public class AgentEndPointWrapper {
 	private static final String MESSAGE_REPLACE_METHOD_KEY = "common.invalid.char.replace";
 	/** Invalidな文字を置換する場合の置換文字のキー */
 	private static final String MESSAGE_REPLACE_CHAR_KEY = "common.invalid.char.replace.to";
-
+	/** 同時アクセス数 */
+	private static final String ENDPOINT_CONCURRENT_ACCESS= "endpoint.concurrent.access";
+	
+	private static final int _conncurrentAccess;
+	private static final Semaphore endpointAccessSem;
+	
 	static {
 		boolean invalidCharReplace = Boolean.parseBoolean(AgentProperties.getProperty(MESSAGE_REPLACE_METHOD_KEY, "false"));
 		XMLUtil.setReplace(invalidCharReplace);
@@ -73,6 +79,47 @@ public class AgentEndPointWrapper {
 			XMLUtil.setReplaceChar(replaceCharString);
 			StringBinder.setReplaceChar(replaceCharString);
 		}
+		
+		// 同時アクセス数をプロパティファイルから取得
+		int accessNum = Integer.MAX_VALUE;
+		String concurrentAccessStr = AgentProperties.getProperty(ENDPOINT_CONCURRENT_ACCESS, String.valueOf(accessNum));
+		try {
+			accessNum = Integer.parseInt(concurrentAccessStr);
+		} catch (NumberFormatException e) {
+			m_log.info("endpoint.concurrent.access uses " + accessNum + ". (" + concurrentAccessStr + " is not collect)");
+		}
+		_conncurrentAccess = accessNum;
+		endpointAccessSem = new Semaphore(_conncurrentAccess);
+		
+		m_log.info(ENDPOINT_CONCURRENT_ACCESS + " = " + _conncurrentAccess);
+	}
+
+	private static int queueCount = 0;
+	private static int activeCount = 0;
+	
+	private static boolean getSemaphore(String method) {
+		m_log.debug("getSemaphore() : call method is " + method + ", queue count = " + ++queueCount);
+		
+		if(endpointAccessSem.getQueueLength() > 0) {
+			m_log.info("getSemaphore() wait num = " + endpointAccessSem.getQueueLength());
+		}
+		
+		try {
+			endpointAccessSem.acquire();
+		} catch (InterruptedException e) {
+			m_log.warn(e.getMessage());
+			return false;
+		}
+		m_log.debug("getSemaphore() : start. active count =  " + ++activeCount + ",queue count = " + --queueCount);
+		return true;
+	}
+	
+	private static void relaseSemaphore(boolean semFlag) {
+		
+		if(semFlag) {
+			endpointAccessSem.release();
+			m_log.debug("relaseSemaphore() : end. active count = " + --activeCount);
+		}
 	}
 
 	public static boolean jobResult(RunResultInfo resultInfo)
@@ -80,6 +127,7 @@ public class AgentEndPointWrapper {
 			InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getAgentEndpoint()) {
+			boolean semFlag = false;
 			try {
 				AgentEndpoint endpoint = (AgentEndpoint) endpointSetting.getEndpoint();
 
@@ -87,11 +135,14 @@ public class AgentEndPointWrapper {
 				resultInfo.setMessage(XMLUtil.ignoreInvalidString(resultInfo.getMessage()));
 				resultInfo.setErrorMessage(XMLUtil.ignoreInvalidString(resultInfo.getErrorMessage()));
 
+				semFlag = getSemaphore("jobResult");
 				return endpoint.jobResult(resultInfo);
 			} catch (WebServiceException e) {
 				wse = e;
 				m_log.info("jobResult " + e.getMessage());
 				EndpointManager.changeEndpoint();
+			} finally {
+				relaseSemaphore(semFlag);
 			}
 		}
 		throw wse;
@@ -103,6 +154,7 @@ public class AgentEndPointWrapper {
 		info.setAgentInfo(Agent.getAgentInfo());
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getAgentEndpoint()) {
+			boolean semFlag = false;
 			try {
 				AgentEndpoint endpoint = (AgentEndpoint) endpointSetting.getEndpoint();
 
@@ -111,12 +163,15 @@ public class AgentEndPointWrapper {
 				outputInfo.setMessage(XMLUtil.ignoreInvalidString(outputInfo.getMessage()));
 				outputInfo.setMessageOrg(XMLUtil.ignoreInvalidString(outputInfo.getMessageOrg()));
 
+				semFlag = getSemaphore("sendMessage");
 				endpoint.sendMessage(info);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
 				m_log.info("WebServiceException " + e.getMessage());
 				EndpointManager.changeEndpoint();
+			} finally {
+				relaseSemaphore(semFlag);
 			}
 		}
 		throw wse;
@@ -139,13 +194,17 @@ public class AgentEndPointWrapper {
 		
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getAgentEndpoint()) {
+			boolean semFlag = false;
 			try {
 				AgentEndpoint endpoint = (AgentEndpoint) endpointSetting.getEndpoint();
+				semFlag = getSemaphore("getHinemosTopic");
 				return endpoint.getHinemosTopic(Agent.getAgentInfo());
 			} catch (WebServiceException e) {
 				wse = e;
 				m_log.info("WebServiceException " + e.getMessage());
 				EndpointManager.changeEndpoint();
+			} finally {
+				relaseSemaphore(semFlag);
 			}
 		}
 		throw wse;
@@ -160,14 +219,18 @@ public class AgentEndPointWrapper {
 
 		// MAIN
 		for (EndpointSetting endpointSetting : EndpointManager.getAgentEndpoint()) {
+			boolean semFlag = false;
 			try {
 				AgentEndpoint endpoint = (AgentEndpoint) endpointSetting.getEndpoint();
+				semFlag = getSemaphore("getCommandExecuteDTOs");
 				wsDTO = (ArrayList<CommandExecuteDTO>)endpoint.getCommandExecuteDTO(Agent.getAgentInfo());
 				return wsDTO;
 			} catch (WebServiceException e) {
 				wse = e;
 				m_log.info("communication failure to manager...", e);
 				EndpointManager.changeEndpoint();
+			} finally {
+				relaseSemaphore(semFlag);
 			}
 		}
 		throw wse;
@@ -181,6 +244,7 @@ public class AgentEndPointWrapper {
 
 		// MAIN
 		for (EndpointSetting endpointSetting : EndpointManager.getAgentEndpoint()) {
+			boolean semFlag = false;
 			try {
 				AgentEndpoint endpoint = (AgentEndpoint) endpointSetting.getEndpoint();
 
@@ -188,12 +252,15 @@ public class AgentEndPointWrapper {
 				result.setStderr(XMLUtil.ignoreInvalidString(result.getStderr()));
 				result.setStdout(XMLUtil.ignoreInvalidString(result.getStdout()));
 
+				semFlag = getSemaphore("putCommandResultDTO");
 				endpoint.putCommandResultDTO(result);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
 				m_log.info("WebServiceException " + e.getMessage());
 				EndpointManager.changeEndpoint();
+			} finally {
+				relaseSemaphore(semFlag);
 			}
 		}
 		throw wse;
@@ -204,13 +271,18 @@ public class AgentEndPointWrapper {
 			InvalidUserPass_Exception, MonitorNotFound_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getAgentEndpoint()) {
+			boolean semFlag = false;
 			try {
 				AgentEndpoint endpoint = (AgentEndpoint) endpointSetting.getEndpoint();
+				
+				semFlag = getSemaphore("getMonitorLogfile");
 				return (ArrayList<MonitorInfo>) endpoint.getMonitorLogfile(Agent.getAgentInfo());
 			} catch (WebServiceException e) {
 				wse = e;
 				m_log.info("WebServiceException " + e.getMessage());
 				EndpointManager.changeEndpoint();
+			} finally {
+				relaseSemaphore(semFlag);
 			}
 		}
 		throw wse;
@@ -221,13 +293,17 @@ public class AgentEndPointWrapper {
 			InvalidUserPass_Exception, MonitorNotFound_Exception, JobMasterNotFound_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getAgentEndpoint()) {
+			boolean semFlag = false;
 			try {
 				AgentEndpoint endpoint = (AgentEndpoint) endpointSetting.getEndpoint();
+				semFlag = getSemaphore("getFileCheckForAgent");
 				return (ArrayList<JobFileCheck>) endpoint.getFileCheckForAgent(Agent.getAgentInfo());
 			} catch (WebServiceException e) {
 				wse = e;
 				m_log.info("WebServiceException " + e.getMessage());
 				EndpointManager.changeEndpoint();
+			} finally {
+				relaseSemaphore(semFlag);
 			}
 		}
 		throw wse;
@@ -238,13 +314,17 @@ public class AgentEndPointWrapper {
 			InvalidUserPass_Exception, MonitorNotFound_Exception, JobMasterNotFound_Exception, FacilityNotFound_Exception, JobInfoNotFound_Exception, JobSessionDuplicate_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getAgentEndpoint()) {
+			boolean semFlag = false;
 			try {
 				AgentEndpoint endpoint = (AgentEndpoint) endpointSetting.getEndpoint();
+				semFlag = getSemaphore("jobFileCheckResult");
 				return endpoint.jobFileCheckResult(jobFileCheck, Agent.getAgentInfo());
 			} catch (WebServiceException e) {
 				wse = e;
 				m_log.info("WebServiceException " + e.getMessage());
 				EndpointManager.changeEndpoint();
+			} finally {
+				relaseSemaphore(semFlag);
 			}
 		}
 		throw wse;
@@ -255,13 +335,17 @@ public class AgentEndPointWrapper {
 			InvalidUserPass_Exception, MonitorNotFound_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getAgentEndpoint()) {
+			boolean semFlag = false;
 			try {
 				AgentEndpoint endpoint = (AgentEndpoint) endpointSetting.getEndpoint();
+				semFlag = getSemaphore("getMonitorWinEvent");
 				return (ArrayList<MonitorInfo>) endpoint.getMonitorWinEvent(Agent.getAgentInfo());
 			} catch (WebServiceException e) {
 				wse = e;
 				m_log.info("WebServiceException " + e.getMessage());
 				EndpointManager.changeEndpoint();
+			} finally {
+				relaseSemaphore(semFlag);
 			}
 		}
 		throw wse;
@@ -272,14 +356,18 @@ public class AgentEndPointWrapper {
 			HinemosUnknown_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getAgentEndpoint()) {
+			boolean semFlag = false;
 			try {
 				AgentEndpoint endpoint = (AgentEndpoint) endpointSetting.getEndpoint();
+				semFlag = getSemaphore("deleteAgent");
 				endpoint.deleteAgent(Agent.getAgentInfo());
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
 				m_log.info("WebServiceException " + e.getMessage());
 				EndpointManager.changeEndpoint();
+			} finally {
+				relaseSemaphore(semFlag);
 			}
 		}
 		throw wse;
@@ -289,13 +377,17 @@ public class AgentEndPointWrapper {
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, IOException {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getAgentEndpoint()) {
+			boolean semFlag = false;
 			try {
 				AgentEndpoint endpoint = (AgentEndpoint) endpointSetting.getEndpoint();
+				semFlag = getSemaphore("downloadModule");
 				return endpoint.downloadModule(filename);
 			} catch (WebServiceException e) {
 				wse = e;
 				m_log.info("WebServiceException " + e.getMessage());
 				EndpointManager.changeEndpoint();
+			} finally {
+				relaseSemaphore(semFlag);
 			}
 		}
 		throw wse;
@@ -305,8 +397,10 @@ public class AgentEndPointWrapper {
 			throws HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception  {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getAgentEndpoint()) {
+			boolean semFlag = false;
 			try {
 				AgentEndpoint endpoint = (AgentEndpoint) endpointSetting.getEndpoint();
+				semFlag = getSemaphore("getAgentLibMap");
 				List<String> list = endpoint.getAgentLibMap();
 				Iterator<String> itr = list.iterator();
 				HashMap<String, String> ret = new HashMap<String, String>();
@@ -318,6 +412,8 @@ public class AgentEndPointWrapper {
 				wse = e;
 				m_log.info("WebServiceException " + e.getMessage());
 				EndpointManager.changeEndpoint();
+			} finally {
+				relaseSemaphore(semFlag);
 			}
 		}
 		throw wse;
@@ -333,14 +429,18 @@ public class AgentEndPointWrapper {
 			agentLibMd5List.add(agentLibMd5.get(str));
 		}
 		for (EndpointSetting endpointSetting : EndpointManager.getAgentEndpoint()) {
+			boolean semFlag = false;
 			try {
 				AgentEndpoint endpoint = (AgentEndpoint) endpointSetting.getEndpoint();
+				semFlag = getSemaphore("setAgentLibMd5");
 				endpoint.setAgentLibMd5(agentLibMd5List, Agent.getAgentInfo());
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
 				m_log.info("WebServiceException " + e.getMessage());
 				EndpointManager.changeEndpoint();
+			} finally {
+				relaseSemaphore(semFlag);
 			}
 		}
 		throw wse;
@@ -352,6 +452,7 @@ public class AgentEndPointWrapper {
 					InvalidUserPass_Exception {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager.getAgentEndpoint()) {
+			boolean semFlag = false;
 			try {
 				AgentEndpoint endpoint = (AgentEndpoint) endpointSetting.getEndpoint();
 
@@ -359,6 +460,7 @@ public class AgentEndPointWrapper {
 				message = XMLUtil.ignoreInvalidString(message);
 				logmsg.setMessage(XMLUtil.ignoreInvalidString(logmsg.getMessage()));
 
+				semFlag = getSemaphore("sendNotify");
 				endpoint.sendNotify(message, logmsg, monitorInfo, rule, Agent.getAgentInfo());
 
 				return;
@@ -366,6 +468,8 @@ public class AgentEndPointWrapper {
 				wse = e;
 				m_log.info("WebServiceException " + e.getMessage());
 				EndpointManager.changeEndpoint();
+			} finally {
+				relaseSemaphore(semFlag);
 			}
 		}
 		throw wse;
@@ -378,14 +482,18 @@ public class AgentEndPointWrapper {
 		WebServiceException wse = null;
 		for (EndpointSetting endpointSetting : EndpointManager
 				.getCloudCommonEndpoint()) {
+			boolean semFlag = false;
 			try {
 				CloudCommonEndpoint endpoint = (CloudCommonEndpoint) endpointSetting
 						.getEndpoint();
+				semFlag = getSemaphore("downloadScripts");
 				return endpoint.downloadScripts(filename);
 			} catch (WebServiceException e) {
 				wse = e;
 				m_log.info("WebServiceException " + e.getMessage());
 				EndpointManager.changeEndpoint();
+			} finally {
+				relaseSemaphore(semFlag);
 			}
 		}
 		throw wse;
