@@ -15,12 +15,15 @@
 
 package com.clustercontrol.bean;
 
+import java.util.ArrayList;
+import java.util.List;
+
 import com.clustercontrol.util.Messages;
 
 /**
  * Hinemosの機能を定数として格納するクラス<BR>
  *
- * @version 4.0.0
+ * @version 4.1.0
  * @since 2.1.2
  */
 public class HinemosModuleConstant {
@@ -36,13 +39,14 @@ public class HinemosModuleConstant {
 	public static final String PLATFORM_LOG_TRANSFER = "PLT_LOG_TRF";
 	/** カレンダ */
 	public static final String PLATFORM_CALENDAR = "PLT_CAL";
+	/** カレンダパターン */
+	public static final String PLATFORM_CALENDAR_PATTERN = "PLT_CAL_PTN";
 	/** アクセス */
 	public static final String PLATFORM_ACCESS 	= "PLT_ACC";
 	/** 重要度判定 */
 	public static final String PLATFORM_PRIORITY_JUDGMENT = "PLT_PRI_JMT";
 	/** リポジトリ */
 	public static final String PLATFORM_REPOSITORY = "PLT_REP";
-
 	/** リポジトリ */
 	public static final String PLATFORM_REPSITORY_NODE = "PLT_REP_NOD";
 	/** リポジトリ */
@@ -87,6 +91,8 @@ public class HinemosModuleConstant {
 	public static final String MONITOR_LOGFILE = "MON_LOGFILE";
 	/** Windowsサービス監視 */
 	public static final String MONITOR_WINSERVICE = "MON_WINSERVICE";
+	/** Windowsイベント監視 */
+	public static final String MONITOR_WINEVENT = "MON_WINEVENT";
 	/** スコープ */
 	public static final String MONITOR_SCOPE = "MON_SCP";
 	/** ステータス */
@@ -119,18 +125,20 @@ public class HinemosModuleConstant {
 	public static final String JOB_SCHEDULE_RUN_DETAIL  = "JOB_SCH_RUN_DTL";
 	/** ジョブ管理 */
 	public static final String JOB_SESSION_FILE = "JOB_SES_FIL";
+	/** ジョブ管理 */
+	public static final String JOB_FILE_CHECK  = "JOB_FCH";
 
 	/**Hinemos自身の処理*/
 	public static final String SYSYTEM = "SYS";
-	/** 障害検知 */
-	public static final String SYSYTEM_TROUBLE_DETECTION = "SYS_TD";
 	/** メンテナンス */
-	public static final String SYSYTEM_MAINTENANCE = "SYS_MTN";
+	public static final String SYSYTEM_MAINTENANCE = "MAINTENANCE";
 	/** セルフチェック */
 	public static final String SYSYTEM_SELFCHECK = "SYS_SFC";
 	/** セルフチェックのデフォルトID */
 	public static final String SYSYTEM_SELFCHECK_ID = "DEFAULT";
 
+	/** レポーティング */
+	public static final String REPORTING = "REPORTING";
 
 	/** 共通プラットフォーム*/
 	public static final int TYPE_PLATFORM  = 100;
@@ -153,6 +161,9 @@ public class HinemosModuleConstant {
 	public static final int TYPE_PLATFORM_REPSITORY_NODE = 111;
 	/** リポジトリ */
 	public static final int TYPE_PLATFORM_REPSITORY_SCOPE = 112;
+	
+	/** カレンダパターン */
+	public static final int TYPE_PLATFORM_CALENDAR_PATTERN = 113;
 
 	/** 一括制御 */
 	public static final int TYPE_COLLECTIVERUN = 200;
@@ -193,6 +204,8 @@ public class HinemosModuleConstant {
 	public static final int TYPE_MONITOR_LOGFILE = 311;
 	/** Windowsサービス監視 */
 	public static final int TYPE_MONITOR_WINSERVICE = 312;
+	/** Windowsイベント監視 */
+	public static final int TYPE_MONITOR_WINEVENT = 313;
 	/** スコープ */
 	public static final int TYPE_MONITOR_SCOPE = 391;
 	/** ステータス */
@@ -225,6 +238,8 @@ public class HinemosModuleConstant {
 	public static final int TYPE_JOB_SCHEDULE_DETAIL  = 507;
 	/** ジョブ管理 */
 	public static final int TYPE_JOB_SESSION_FILE = 508;
+	/** ジョブ管理 */
+	public static final int TYPE_JOB_FILE_CHECK = 509;
 
 	/**Hinemos自身の書処理*/
 	public static final int TYPE_SYSYTEM =600;
@@ -235,6 +250,8 @@ public class HinemosModuleConstant {
 	/** セルフチェック */
 	public static final int TYPE_SYSYTEM_SELFCHECK = 603;
 
+	/** レポーティング */
+	public static final int TYPE_REPORTING = 701;
 
 	/** リポジトリ */
 	public static final String STRING_PLATFORM_REPOSITORY = Messages.getString("repository");
@@ -242,8 +259,12 @@ public class HinemosModuleConstant {
 	public static final String STRING_PLATFORM_ACCESS = Messages.getString("accesscontrol");
 	/** カレンダ */
 	public static final String STRING_PLATFORM_CALENDAR = Messages.getString("calendar");
+	/** カレンダパターン */
+	public static final String STRING_PLATFORM_CALENDAR_PATTERN = Messages.getString("calendar.pattern");
 	/** 通知 */
-	public static final String STRING_PLATFORM_NOTIFY = Messages.getString("notify.id");
+	public static final String STRING_PLATFORM_NOTIFY = Messages.getString("notify");
+	/** メールテンプレート */
+	public static final String STRING_PLATFORM_MAIL_TEMPLATE = Messages.getString("mail.template");
 	/** 重要度判定 */
 	public static final String STRING_PLATFORM_PRIORITY_JUDGMENT = Messages.getString("priority.judgment");
 	/** ログ転送 */
@@ -278,12 +299,18 @@ public class HinemosModuleConstant {
 	public static final String STRING_MONITOR_PORT = Messages.getString("port.monitor");
 	/** Windowsサービス監視 */
 	public static final String STRING_MONITOR_WINSERVICE = Messages.getString("winservice.monitor");
+	/** Windowsイベント監視 */
+	public static final String STRING_MONITOR_WINEVENT = Messages.getString("winevent.monitor");
 	/** 性能管理 */
 	public static final String STRING_PERFORMANCE = Messages.getString("performance");
 	/** ジョブ管理 */
 	public static final String STRING_JOB = Messages.getString("job.management");
 	/** ジョブ管理 */
 	public static final String STRING_JOB_MST = Messages.getString("job.management");
+	/** ジョブ管理（スケジュール） */
+	public static final String STRING_JOB_SCHEDULE = Messages.getString("schedule");
+	/** ジョブ管理（ファイルチェック） */
+	public static final String STRING_JOB_FILE_CHECK = Messages.getString("file.check");
 
 	/** 障害検知 */
 	public static final String STRING_SYSYTEM_TROUBLE_DETECTION = Messages.getString("trouble.detection");
@@ -291,6 +318,9 @@ public class HinemosModuleConstant {
 	public static final String STRING_SYSYTEM_MAINTENANCE = Messages.getString("maintenance.name");
 	/** セルフチェック */
 	public static final String STRING_SYSYTEM_SELFCHECK = Messages.getString("selfcheck.name");
+	
+	/** レポーティング */
+	public static final String STRING_REPORTING = Messages.getString("reporting");
 
 	/** マネージャ操作ログタイトル */
 	/** リポジトリ */
@@ -331,6 +361,8 @@ public class HinemosModuleConstant {
 	public static final String LOG_PREFIX_MONITOR_PORT = "[Port]";
 	/** Windowsサービス監視 */
 	public static final String LOG_PREFIX_MONITOR_WINSERVICE = "[WinService]";
+	/** Windowsイベント監視 */
+	public static final String LOG_PREFIX_MONITOR_WINEVENT = "[WinEvent]";
 	/** 性能管理 */
 	public static final String LOG_PREFIX_PERFORMANCE = "[Collector]";
 	/** ジョブ管理 */
@@ -343,8 +375,45 @@ public class HinemosModuleConstant {
 	public static final String LOG_PREFIX_NODEMAP = "[NodeMap]";
 	/** 仮想化管理 */
 	public static final String LOG_PREFIX_VM = "[VM]";
+	/** レポーティング */
+	public static final String LOG_PREFIX_REPORTING = "[Reporting]";
 
+	
+	private static List<ExtensionType> extensionTypeList = new ArrayList<ExtensionType>();
+	
+	public static List<ExtensionType> getExtensionTypeList(){
+		return extensionTypeList;
+	}
 
+	public static class ExtensionType{
+		private String typeId;
+		private int typeCode;
+		private String stringType;
+		
+		public ExtensionType(String typeId, int typeCode, String stringType){
+			this.typeId = typeId;
+			this.typeCode = typeCode;
+			this.stringType = stringType;
+		}
+		
+		public String getTypeId() {
+			return typeId;
+		}
+
+		public int getTypeCode() {
+			return typeCode;
+		}
+
+		public String getStringType() {
+			return stringType;
+		}
+	}
+	
+	public static void addExtensionType(ExtensionType extensionType){
+		extensionTypeList.add(extensionType);
+	}
+	
+	
 	/**
 	 * 機能略記が存在するかチェックします。
 	 * 
@@ -357,6 +426,7 @@ public class HinemosModuleConstant {
 				typeId.equals(PLATFORM_MAIL_TEMPLATE) ||
 				typeId.equals(PLATFORM_LOG_TRANSFER) ||
 				typeId.equals(PLATFORM_CALENDAR) ||
+				typeId.equals(PLATFORM_CALENDAR_PATTERN) ||
 				typeId.equals(PLATFORM_ACCESS) ||
 				typeId.equals(PLATFORM_PRIORITY_JUDGMENT) ||
 				typeId.equals(PLATFORM_REPOSITORY) ||
@@ -384,6 +454,7 @@ public class HinemosModuleConstant {
 				typeId.equals(MONITOR_STATUS) ||
 				typeId.equals(MONITOR_EVENT) ||
 				typeId.equals(MONITOR_WINSERVICE) ||
+				typeId.equals(MONITOR_WINEVENT) ||
 				typeId.equals(PERFORMANCE) ||
 				typeId.equals(PERFORMANCE_RECORD) ||
 				typeId.equals(PERFORMANCE_REALTIME) ||
@@ -395,15 +466,22 @@ public class HinemosModuleConstant {
 				typeId.equals(JOB_SCHEDULE) ||
 				typeId.equals(JOB_SCHEDULE_RUN_DETAIL) ||
 				typeId.equals(JOB_SESSION_FILE ) ||
+				typeId.equals(JOB_FILE_CHECK ) ||
 				typeId.equals(SYSYTEM ) ||
-				typeId.equals(SYSYTEM_TROUBLE_DETECTION ) ||
 				typeId.equals(SYSYTEM_MAINTENANCE) ||
-				typeId.equals(SYSYTEM_SELFCHECK)){
+				typeId.equals(SYSYTEM_SELFCHECK) ||
+				typeId.equals(REPORTING)){
 
 			return true;
-		}else
-			return false;
-
+		} else if(!extensionTypeList.isEmpty()){
+			for(ExtensionType extensionType: extensionTypeList){
+				if(typeId.equals(extensionType.getTypeId())){
+					return true;
+				}
+			}
+		}
+		
+		return false;
 	}
 
 
@@ -456,6 +534,8 @@ public class HinemosModuleConstant {
 			return STRING_MONITOR_PORT;
 		} else if (type == TYPE_MONITOR_WINSERVICE) {
 			return STRING_MONITOR_WINSERVICE;
+		} else if (type == TYPE_MONITOR_WINEVENT) {
+			return STRING_MONITOR_WINEVENT;
 		} else if (type == TYPE_PERFORMANCE) {
 			return STRING_PERFORMANCE;
 		} else if (type == TYPE_JOB) {
@@ -468,6 +548,14 @@ public class HinemosModuleConstant {
 			return STRING_SYSYTEM_MAINTENANCE;
 		} else if (type == TYPE_SYSYTEM_SELFCHECK) {
 			return STRING_SYSYTEM_SELFCHECK;
+		} else if (type == TYPE_REPORTING) {
+			return STRING_REPORTING;
+		} else if(!extensionTypeList.isEmpty()){
+			for(ExtensionType extensionType: extensionTypeList){
+				if(type == extensionType.getTypeCode()){
+					return extensionType.getStringType();
+				}
+			}
 		}
 		return "";
 	}
@@ -519,6 +607,8 @@ public class HinemosModuleConstant {
 			return TYPE_MONITOR_PORT;
 		} else if (string.equals(STRING_MONITOR_WINSERVICE)) {
 			return TYPE_MONITOR_WINSERVICE;
+		} else if (string.equals(STRING_MONITOR_WINEVENT)) {
+			return TYPE_MONITOR_WINEVENT;
 		} else if (string.equals(STRING_MONITOR_SYSTEMLOG)) {
 			return TYPE_MONITOR_SYSTEMLOG;
 		} else if (string.equals(STRING_PERFORMANCE)) {
@@ -533,6 +623,14 @@ public class HinemosModuleConstant {
 			return TYPE_SYSYTEM_MAINTENANCE;
 		} else if (string.equals(STRING_SYSYTEM_SELFCHECK)) {
 			return TYPE_SYSYTEM_SELFCHECK;
+		} else if (string.equals(STRING_REPORTING)) {
+			return TYPE_REPORTING;
+		} else if(!extensionTypeList.isEmpty()){
+			for(ExtensionType extensionType: extensionTypeList){
+				if(string.equals(extensionType.getStringType())){
+					return extensionType.getTypeCode();
+				}
+			}
 		}
 		return -1;
 	}
@@ -551,12 +649,16 @@ public class HinemosModuleConstant {
 			return STRING_PLATFORM_PRIORITY_JUDGMENT;
 		} else if (string.equals(PLATFORM_CALENDAR)) {
 			return STRING_PLATFORM_CALENDAR;
+		} else if (string.equals(PLATFORM_CALENDAR_PATTERN)) {
+			return STRING_PLATFORM_CALENDAR_PATTERN;
 		} else if (string.equals(PLATFORM_LOG_TRANSFER)) {
 			return STRING_PLATFORM_LOG_TRANSFER;
 		} else if (string.equals(PLATFORM_REPOSITORY)) {
 			return STRING_PLATFORM_REPOSITORY;
 		} else if (string.equals(PLATFORM_NOTIFY)) {
 			return STRING_PLATFORM_NOTIFY;
+		} else if (string.equals(PLATFORM_MAIL_TEMPLATE)) {
+			return STRING_PLATFORM_MAIL_TEMPLATE;
 		} else if (string.equals(COLLECTIVERUN)) {
 			return STRING_COLLECTIVERUN;
 		} else if (string.equals(MONITOR)) {
@@ -583,6 +685,8 @@ public class HinemosModuleConstant {
 			return STRING_MONITOR_PORT;
 		} else if (string.equals(MONITOR_WINSERVICE)) {
 			return STRING_MONITOR_WINSERVICE;
+		} else if (string.equals(MONITOR_WINEVENT)) {
+			return STRING_MONITOR_WINEVENT;
 		} else if (string.equals(MONITOR_SYSTEMLOG)) {
 			return STRING_MONITOR_SYSTEMLOG;
 		} else if (string.equals(MONITOR_LOGFILE)) {
@@ -593,12 +697,22 @@ public class HinemosModuleConstant {
 			return STRING_JOB;
 		} else if (string.equals(JOB_MST)) {
 			return STRING_JOB_MST;
-		} else if (string.equals(SYSYTEM_TROUBLE_DETECTION)) {
-			return STRING_SYSYTEM_TROUBLE_DETECTION;
+		} else if (string.equals(JOB_SCHEDULE)) {
+			return STRING_JOB_SCHEDULE;
+		} else if (string.equals(JOB_FILE_CHECK)) {
+			return STRING_JOB_FILE_CHECK;
 		} else if (string.equals(SYSYTEM_MAINTENANCE)) {
 			return STRING_SYSYTEM_MAINTENANCE;
 		} else if (string.equals(SYSYTEM_SELFCHECK)) {
 			return STRING_SYSYTEM_SELFCHECK;
+		} else if (string.equals(REPORTING)) {
+			return STRING_REPORTING;
+		} else if(!extensionTypeList.isEmpty()){
+			for(ExtensionType extensionType: extensionTypeList){
+				if(string.equals(extensionType.getTypeId())){
+					return extensionType.getStringType();
+				}
+			}
 		}
 		return "";
 	}
